import { Body, Controller, Delete, Param, Patch, Post, Put } from "@nestjs/common";
import { UserPrivilegeDataOrchestrator } from "../domain/usecases/user-privilege-data.orchestrator";
import { CreateUserPrivilegeDto } from "./dto/create-user-privilege.dto";
import { MODULE_NAME } from "src/core/strings/constants/module.constants";
import { ApiTags } from "@nestjs/swagger";
import { Unprotected } from "src/core/guards";
import * as Nano  from 'nano'
import { UserPrivilegeEntity } from "../domain/entities/user-privilege.entity";

@ApiTags(`${MODULE_NAME.USER_PRIVILEGE.split('-').join(' ')} - data`)
@Controller(MODULE_NAME.USER_PRIVILEGE)
@Unprotected()
export class UserPrivilegeDataController {
    constructor(
        private orchestrator: UserPrivilegeDataOrchestrator
    ) {}

    @Post()
    async create(
        @Body() data: CreateUserPrivilegeDto,
    ): Promise<UserPrivilegeEntity> {
        return await this.orchestrator.create(data);
    }

    @Put(':id')
    async update(
        @Param('id') dataId: string,
        @Body() data: CreateUserPrivilegeDto,
    ): Promise<UserPrivilegeEntity> {
        return await this.orchestrator.update(dataId, data);
    }

    @Delete(':id')
    async delete(
        @Param('id') dataId: string,
    ): Promise<String> {
        return await this.orchestrator.delete(dataId);
    }

    @Patch(':id/active')
    async active(
        @Param('id') dataId: string,
    ): Promise<String> {
        return await this.orchestrator.active(dataId);
    }
    
    @Patch(':id/confirm')
    async confirm(
        @Param('id') dataId: string,
    ): Promise<String> {
        return await this.orchestrator.confirm(dataId);
    }

    @Patch(':id/inactive')
    async inactive(
        @Param('id') dataId: string,
    ): Promise<String> {
        return await this.orchestrator.inactive(dataId);
    }


    // @Post('pouch')
    // async createDoc(
    //     @Body() entity: CreateUserPrivilegeDto
    // ) {
    //     try {
    //         let n = Nano('http://admin:secret@127.0.0.1:5984')
    //         let db = await n.db.create('people')
    //     } catch (error) {
    //         console.log(error, 'dsa')
    //     }
    // }

    // @Post('pouch/doc')
    // async createDocs(
    //     @Body() entity: CreateUserPrivilegeDto
    // ) {
    //     try {
    //         let n = Nano('http://admin:secret@127.0.0.1:5984')
    //         const people = n.use('people');
    //         const data = {
    //             id: '1212',
    //             name: 'dsadas'
    //         }
    //         return await people.insert({'_id': 'dsa', '_rev': JSON.stringify({'dsa': 'dsa'})})
    //     } catch (error) {
    //         console.log(error, 'dsa')
    //     }
    // }

    // @Get('pouch')
    // async getDoc(
    // ) {
    //     try {
    //         let n = Nano('http://admin:secret@127.0.0.1:5984')
    //         const people = n.use('people');
    //         // return people.get();
    //     } catch (error) {
    //         console.log(error, 'dsa')
    //     }
    // }
}